
library(shiny)

# Define UI for application that draws a histogram
ui <- fluidPage(

    # Application title
    titlePanel("Measurement Models for Democracy"),

    # Sidebar with a slider input for number of bins 
    sidebarLayout(
        sidebarPanel(
            checkboxGroupInput("vars", "Variables to Include", 
                choices = c(
                    "Voice: Electoral Competition"="lgates", 
                    "Voice: Competitiveness of Executive Recruitment" = "xrcomp", 
                    "Voice: Competitiveness of Political Participation" = "parcomp", 
                    "Voice: Alvarez et al." = "aclp", 
                    "Voice: Bernhard et al." = "bnr", 
                    "Voice: Suffrage" = "sfrg", 
                    "Veto: Checks" = "log_checks", 
                    "Veto: Political Constraints" = "polconiii", 
                    "Veto: Executive Constraints" = "xconst", 
                    "Veto: Law & Order" = "laworder", 
                    "Veto: Sub-federal Veto"), selected = c("lgates", "xrcomp", "parcomp", "aclp", "bnr", "sfrg")), 
            selectInput("year", "Year", choices=1981:1999, selected=1999)
        ),

        # Show a plot of the generated distribution
        mainPanel(
           plotOutput("plot")
        )
    )
)

# Define server logic required to draw a histogram
server <- function(input, output) {

    # Load packages and Data    
    library(spData)
    library(psych)
    library(sf)
    library(tmap)
    library(leaflet)
    load("tutorial.rda")
    data(world)
    library(countrycode)
    library(dplyr)
    dat$iso_a2 <- countrycode(dat$ccode, "cown", "iso2c")
    output$plot <- renderPlot({
        # select variables and estimate appropriate measurement model
        tmp <- dat %>% dplyr:::select(input$vars)
        f <- fa(tmp, nfactors=1, fm="pa")
        # put democracy score in data
        dat$dem_score <- f$scores[,1]
        # filter data to get correct year
        tmp <- dat %>% filter(year == input$year) %>% dplyr:::select("iso_a2", "dem_score")
        # merge data together 
        world <- merge(world, tmp, all.x=TRUE, all.y=FALSE)
        # make the map
        tm1 <- tm_shape(world) + 
            tm_fill(col="dem_score", palette = "RdBu", title="Democracy")   + 
            tm_borders(col="gray50", lwd=.5)
        print(tm1)
            })
}

# Run the application 
shinyApp(ui = ui, server = server)
